@@ -264,6 +264,15 @@ extract_from_BiCop <- function(args) {
         args$par <- args$obj$par
         args$par2 <- args$obj$par2
     }
+    # make sure the family has appropriate form
+    if (!is.numeric(args$family)) {
+        stop(paste0("'family' must be numeric (not ", class(args$family), ")"),
+             call. = FALSE)
+    }
+    if (!isTRUE(all.equal(args$family, round(args$family)))) {
+        stop("'family' must be an integer", call. = FALSE)
+    }
+
     # set parameter if independence copula was specified without
     if (is.null(args$par) & (all(args$family == 0)))
         args$par <- 0
@@ -500,7 +509,7 @@ check_est_pars <- function(args) {
                             BB8 = c(6, 1))
     }
 
-    if (!is.null(args$family)) {
+    if (!is.null(args[["family"]])) {
         if (!(all(args$family %in% allfams)))
             stop("\n In ", args$call[1], ": ",
                  "Copula family not implemented.",
@@ -519,8 +528,8 @@ check_est_pars <- function(args) {
             stop("\n In ", args$call[1], ": ",
                  "Estimation method has to be either 'mle' or 'itau'.",
                  call. = FALSE)
-        if (!is.null(args$family)) {
-            if ((args$method == "itau") && (!(args$family %in% c(0, 2, allfams[onepar])))) {
+        if (!is.null(args[["family"]])) {
+            if ((args$method == "itau") && (!all(args$family %in% c(0, 2, allfams[onepar])))) {
                 warning(" In ", args$call[1], ": ",
                         "For two parameter copulas the estimation method 'itau' cannot ",
                         "be used. The method is automatically set to 'mle'.",
